<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.21
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\Assignments;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

use FPFramework\Base\Assignment;

class Grouplevel extends Assignment
{
	/**
     *  md5 hash used for caching the groups map
     *
     *  @var string
     */
    protected $_groupsHash;

    /**
     *  Constructor
     *
     *  @param object $options
     *  @param object $factory
     */
    public function __construct($options, $factory)
    {
        parent::__construct($options, $factory);

        $_groupsHash = md5('FPFramework\Assignments\User_groupsHash');
	}
	
   	/**
   	 *  Check user grouplevel
   	 *
   	 *  @return  bool   Returns true if the Referrer URL contains any of the selection URLs 
   	 */
	public function pass()
	{
		$groups = $this->getGroups();

		return $this->passSimple($this->value(), $this->selection); 
	}

    /**
     *  Returns the assignment's value
     * 
     *  @return array User groups
     */
	public function value()
	{
		return !empty($this->user->roles) ? array_values($this->user->roles) : $this->getAuthorisedGroups();
    }
    
    private function getAuthorisedGroups()
    {
        return [
            'guest' => fpframework()->_('FPF_GUEST')
        ];
    }

	/**
     *  Returns User Groups map (ID => Name)
     *
     *  @return array
     */
    protected function getGroups()
    {
		// check cache
		if ($groups = wp_cache_get($this->_groupsHash))
		{
			return $groups;
        }

        $groups = \FPFramework\Helpers\UserHelper::getUserRoles();
        $groups = \FPFramework\Helpers\UserHelper::parseData($groups);
        
		// set cache
		wp_cache_set($this->_groupsHash, $groups);

        return $groups;
    }
}
