<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.21
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Base\Factory;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class Session
{
    /**
     * The session id
     * 
     * @var  string
     */
    private $session_id;
    
	/**
	 * Get Session ID
	 * 
	 * @return  string
	 */
    public function getSessionID()
    {
        if (!$this->session_id)
        {
            $this->setSessionID();
        }
        
		return $this->session_id;
    }

    /**
     * Sets the session ID
     * 
     * @param   string  $session_id
     * 
     * @return  void
     */
    public function setSessionID($session_id = null)
    {
        if (!$session_id)
        {
            $this->session_id = session_id();
            return;
        }

        $this->session_id = $session_id;
    }

    /**
     * Gets Session value
     * 
     * @return  string
     */
    public function get($key)
    {
        if (!isset($_SESSION[$key]))
        {
            return false;
        }

        return $_SESSION[$key];
    }

    /**
     * Sets session key, value
     * 
     * @return  void
     */
    public function set($key, $value)
    {
        return $_SESSION[$key] = $value;
    }
}