<?php
/**
 * @package         FirePlugins Framework
 * @version         1.0.21
 * 
 * @author          FirePlugins <info@fireplugins.com>
 * @link            https://www.fireplugins.com
 * @copyright       Copyright © 2022 FirePlugins All Rights Reserved
 * @license         GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
*/

namespace FPFramework\Helpers\Controls;

if (!defined('ABSPATH'))
{
	exit; // Exit if accessed directly.
}

class Responsive
{
	/**
	 * Responsive breakpoints
	 * 
	 * @var  array
	 */
	public static $breakpoints = [
		'desktop',
		'tablet',
		'mobile'
	];
    
    /**
     * Given a responsive value, we prepare its CSS for each breakpoint.
     * 
     * @param   array   $value
     * @param   string  $prefix
     * @param   string  $unit
     * 
     * @return  mixed
     */
    public static function prepareResponsiveControlValue($value, $prefix = '', $unit = '')
    {
        if (!$value || !is_array($value))
        {
            return;
        }

        if (!is_string($prefix) || !is_string($unit))
        {
            return;
        }

        $css = [];

        foreach ($value as $key => $_value)
        {
            if ($_value === '')
            {
                continue;
            }
            
            $css[$key] = $prefix . ': ' . $_value . $unit . ';';
        }

        return $css;
    }
}